@@ -26,7 +26,7 @@ get_projects <- function(){
 RAVEProject <- R6::R6Class(
   classname = 'RAVEProject',
   class = TRUE,
-  portable = TRUE,
+  portable = FALSE,
   private = list(
     .name = character(0),
     .path = character(0)
@@ -105,6 +105,11 @@ RAVEProject <- R6::R6Class(
     #' @field name project name, character
     name = function(){
       private$.name
+    },
+
+    #' @field pipeline_path path to pipeline scripts under project's folder
+    pipeline_path = function(){
+      file.path(private$.path, '_project_pipeline')
     }
   )
 )
